@@ -85,7 +85,7 @@ class ImageRecognition(object):
             base_var_list = tf.get_collection(tf.GraphKeys.GLOBAL_VARIABLES)
         
         with tf.variable_scope('resnet_v2_101'):
-            depth = out.get_shape().as_list()[-1]
+            depth = out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = new_fc_layer(out, 
                                 num_inputs = depth, 
                                 num_outputs = len(self.classes), 
@@ -166,7 +166,7 @@ class ImageRecognition(object):
                                     use_batchnorm=True) 
                 size = out.get_shape().as_list()[1]
             
-            depth = out.get_shape().as_list()[-1]
+            depth = out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
             out = new_fc_layer(out, 
                                 num_inputs = depth, 
